### 设置你的minio-py Github仓库
Fork [minio-py upstream](https://github.com/minio/minio-py/fork)源码仓库到你自己的仓库。

```sh
$ git clone https://github.com/$USER_ID/minio-py
$ cd minio-py
$ python setup.py install
...
```

### 开发者指南

``minio-py``欢迎你的贡献。为了让大家配合的更加默契，我们做出如下约定：

* fork项目并修改，我们鼓励大家使用pull requests进行代码相关的讨论。
    - Fork项目
    - 创建你的特性分支 (git checkout -b my-new-feature)
    - Commit你的修改(git commit -am 'Add some feature')
    - Push到远程分支(git push origin my-new-feature)
    - 创建一个Pull Request
